@@ -998,7 +998,7 @@ pub struct GetPeerInfoResult {
     /// Local address as reported by the peer
     // TODO: use a type for addrlocal
     pub addrlocal: Option<String>,
-    /// Network (ipv4, ipv6, or onion) the peer connected throug
+    /// Network (ipv4, ipv6, or onion) the peer connected through
     /// Added in Bitcoin Core v0.21
     pub network: Option<GetPeerInfoResultNetwork>,
     /// The services offered
@@ -1066,13 +1066,17 @@ pub struct GetPeerInfoResult {
 }
 
 #[derive(Copy, Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
-#[serde(rename_all = "lowercase")]
+#[serde(rename_all = "snake_case")]
 pub enum GetPeerInfoResultNetwork {
     Ipv4,
     Ipv6,
     Onion,
-    // this is undocumented upstream
+    #[deprecated]
     Unroutable,
+    NotPubliclyRoutable,
+    I2p,
+    Cjdns,
+    Internal,
 }
 
 #[derive(Copy, Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
@@ -1607,6 +1611,7 @@ pub enum AddressType {
     Legacy,
     P2shSegwit,
     Bech32,
+    Bech32m,
 }
 
 /// Used to represent arguments that can either be an address or a public key.
@@ -1686,3 +1691,37 @@ where
     }
     Ok(Some(res))
 }
+
+/// Import Descriptor Request
+#[derive(Serialize, Clone, PartialEq, Eq, Debug)]
+pub struct ImportDescriptorRequest {
+    pub active: bool,
+    #[serde(rename = "desc")]
+    pub descriptor: String,
+    pub range: [i64; 2],
+    pub next_index: i64,
+    pub timestamp: String,
+    pub internal: bool,
+}
+
+impl ImportDescriptorRequest {
+    /// Create a new Import Descriptor request providing just the descriptor and internal flags
+    pub fn new(descriptor: &str, internal: bool) -> Self {
+        ImportDescriptorRequest {
+            descriptor: descriptor.to_string(),
+            internal,
+            active: true,
+            range: [0, 100],
+            next_index: 0,
+            timestamp: "now".to_string(),
+        }
+    }
+}
+
+/// Imported Descriptor Result
+#[derive(Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
+pub struct ImportDescriptorResult {
+    pub success: bool,
+    pub warnings: Option<Vec<String>>,
+    pub error: Option<String>,
+}
